@@ -22,7 +22,7 @@ Test::Run::CmdLine - Analyze tests from the command line using Test::Run
 
 use vars (qw($VERSION));
 
-$VERSION = '0.0128';
+$VERSION = '0.0130';
 
 use Moose;
 
@@ -465,7 +465,7 @@ sub add_to_backend_plugins
 
 =head1 AUTHORS
 
-Shlomi Fish, C<< <shlomif@iglu.org.il> >>
+Shlomi Fish, L<http://www.shlomifish.org/> .
 
 =head1 BUGS
 
